# Generated by Django 4.2.20 on 2025-05-03 06:12

import timezone_field.fields
from django.db import migrations, models

import touchtechnology.common.db.models


class Migration(migrations.Migration):

    dependencies = [
        ("competition", "0049_match_live_stream_thumbnail"),
    ]

    operations = [
        migrations.AlterField(
            model_name="place",
            name="timezone",
            field=timezone_field.fields.TimeZoneField(
                blank=True, max_length=50, null=True, use_pytz=False
            ),
        ),
        migrations.AlterField(
            model_name="season",
            name="live_stream_thumbnail",
            field=models.URLField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="season",
            name="timezone",
            field=timezone_field.fields.TimeZoneField(
                blank=True, max_length=50, null=True, use_pytz=False
            ),
        ),
        migrations.AlterField(
            model_name="team",
            name="team_clashes",
            field=touchtechnology.common.db.models.ManyToManyField(
                blank=True,
                help_text="Select any teams that must not play at the same time.",
                to="competition.team",
                verbose_name="Don't clash",
            ),
        ),
    ]
