{% extends "base.html" %}
{% load tz i18n %}

{% block body_class %}{{ block.super }} competitions{% endblock %}

{% block full_content %}
	{% get_current_timezone as TIME_ZONE %}

	{% timezone season.timezone|default:TIME_ZONE %}
		{% get_current_timezone as SEASON_TIME_ZONE %}

		{% if TIME_ZONE != SEASON_TIME_ZONE %}
			{% block timezone %}
				<div class="container_16">
					<div class="grid_16">
						<p>{% blocktrans %}All dates &amp; times below have been adjusted to <strong>{{ SEASON_TIME_ZONE }}</strong> timezone.{% endblocktrans %}</p>
					</div>
				</div>
			{% endblock %}
		{% endif %}
	{% endtimezone %}

	{{ block.super }}
{% endblock %}
