{% extends "base.html" %}

{% block body_class %}{{ block.super }} news{% endblock %}

{% block content %}
	{% block news_content %}{% endblock %}
	{% block related_content %}{% endblock %}
{% endblock %}
